% ------------------------------------
% Universidad de Costa Rica
% Facultad de Ingeniería
%
% Jornadas de Investigación
% ------------------------------------

% Declaraciones iniciales
% -----------------------

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{jornadas}[]

% Cargar la clase base ('article')
% --------------------------------

\LoadClass[letterpaper,11pt]{article}

% Paquetes requeridos
% -------------------

% Tipografía Times New Roman
\RequirePackage{times}

% General
\RequirePackage[utf8]{inputenc}
\RequirePackage[spanish]{babel}
    \addto\captionsspanish{\renewcommand{\tablename}{\textsc{Tabla}}}
    \addto\captionsspanish{\renewcommand{\figurename}{Fig.}}
\RequirePackage{csquotes}
\RequirePackage{hyperref}
    \urlstyle{same}

% Bibliografía
\RequirePackage[style=ieee]{biblatex}

% Fórmulas matemáticas
\RequirePackage{amsmath, amssymb, amsfonts}

% Diagramación de la página
\RequirePackage{geometry}  
    \geometry{left=21mm,right=21mm,top=21mm,bottom=21mm}
\RequirePackage{setspace}
    \onehalfspacing
\RequirePackage{sectsty}
    \sectionfont{\MakeUppercase}
\RequirePackage{caption}
    \captionsetup[table]{
      labelsep=newline,
      justification=justified,
    }
\RequirePackage{lineno}

% Gráficos, tablas, iconos
\RequirePackage{graphicx}
    \graphicspath{{./imagenes/}}
\RequirePackage{subcaption}
\RequirePackage{float}
\RequirePackage{booktabs}
\RequirePackage{fontawesome}

% Gráficos vectoriales
\RequirePackage{tikz}
\RequirePackage{pgfplots}
    \pgfplotsset{compat=1.17}
    \newlength\figureheight 
	\newlength\figurewidth

% Base de datos de autores
\RequirePackage{datatool}

% Definición de datos globales del proyecto
% -----------------------------------------

% Datos del artículo
\def\titulo#1{\gdef\@titulo{#1}}
\def\thetitle#1{\gdef\@thetitle{#1}}
\def\palabras#1{\gdef\@palabras{#1}}

% Nombre de los autores
\def\autorA#1{\gdef\@autorA{#1}}
\def\posicionA#1{\gdef\@posicionA{#1}}
\def\institucionA#1{\gdef\@institucionA{#1}}
\def\emailA#1{\gdef\@emailA{#1}}
\def\orcidA#1{\gdef\@orcidA{#1}}

\def\autorB#1{\gdef\@autorB{#1}}
\def\posicionB#1{\gdef\@posicionB{#1}}
\def\institucionB#1{\gdef\@institucionB{#1}}
\def\emailB#1{\gdef\@emailB{#1}}
\def\orcidB#1{\gdef\@orcidB{#1}}

\def\autorC#1{\gdef\@autorC{#1}}
\def\posicionC#1{\gdef\@posicionC{#1}}
\def\institucionC#1{\gdef\@institucionC{#1}}
\def\emailC#1{\gdef\@emailC{#1}}
\def\orcidC#1{\gdef\@orcidC{#1}}

% 1. Formato de título (encabezado)
% ---------------------------------

\newcommand{\titulos}{
    {
    \singlespacing
    \begin{center}
        {\LARGE\bfseries\@titulo}
    	\vskip 1em
        {\large\bfseries\@thetitle}
    	\vskip 1em
    \end{center}
    }
}

% 2. Lista de autores
% ----------------------------

\DTLnewdb{autores}

\newcommand{\autor}[5]{
    \DTLnewrow{autores}
    \DTLnewdbentry{autores}{nombre}{#1}
    \DTLnewdbentry{autores}{posicion}{#2}
    \DTLnewdbentry{autores}{institucion}{#3}
    \DTLnewdbentry{autores}{correo}{#4}
    \DTLnewdbentry{autores}{orcid}{#5}
}

\newcommand{\listadeautores}{
    {
    \singlespacing
    \centering
    \DTLforeach{autores}{\nombre=nombre, \posicion=posicion, \institucion=institucion, \correo=correo, \orcid=orcid}{
            {\normalsize\nombre} \\
    	    {\itshape\posicion} \\
    	    {\itshape\institucion} \\
    	    {\itshape\href{mailto:\correo}{\correo}} \\
    	    {\small\orcid}
            \vskip 1em
        }
    }
}

% 2. Formato de palabras clave
% ----------------------------

\newcommand{\palabrasclave}{
    \bigskip
    {\noindent\bfseries Palabras clave:}
    {\itshape \@palabras}
}

% 3. Licencia
% -----------

\newcommand{\licencia}{
\vfill
\begin{center}
\small\itshape
Este documento fue elaborado bajo la licencia abierta Creative Commons en su modalidad \href{https://creativecommons.org/licenses/by-nc-sa/4.0/deed.es}{Atribución-NoComercial-CompartirIgual 4.0 Internacional (CC BY-NC-SA 4.0)}
\end{center}
}

% 4. Formato de secciones y sub-secciones
% ---------------------------------------

% Numeración en números romanos
\renewcommand*{\thesection}{\Roman{section}}

% Numeración alfabética
\renewcommand*{\thesubsection}{\Alph{subsection}}

%%%%%%%%%
\endinput
%%%%%%%%%